@@ -6,17 +6,18 @@ from werkzeug.datastructures import Headers
 from werkzeug.datastructures import ImmutableMultiDict
 from werkzeug.wrappers import Request
 
-from openapi_core.validation.request.datatypes import RequestParameters
+from openapi_core.datatypes import RequestParameters
 
 # http://flask.pocoo.org/docs/1.0/quickstart/#variable-rules
 PATH_PARAMETER_PATTERN = r"<(?:(?:string|int|float|path|uuid):)?(\w+)>"
 
 
 class WerkzeugOpenAPIRequest:
-
     path_regex = re.compile(PATH_PARAMETER_PATTERN)
 
     def __init__(self, request: Request):
+        if not isinstance(request, Request):
+            raise TypeError(f"'request' argument is not type of {Request}")
         self.request = request
 
         self.parameters = RequestParameters(
@@ -31,7 +32,7 @@ class WerkzeugOpenAPIRequest:
 
     @property
     def path(self) -> str:
-        return self.request.path
+        return self.get_path(self.request.path)
 
     @property
     def method(self) -> str:
@@ -44,3 +45,6 @@ class WerkzeugOpenAPIRequest:
     @property
     def mimetype(self) -> str:
         return self.request.mimetype
+
+    def get_path(self, path: str) -> str:
+        return "".join([self.request.root_path, path])
